Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(292)

Unified Diff: components/autofill/core/browser/autofill_metrics.h

Issue 1392623002: [Autofill] Add metric for profile action on form submitted (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_metrics.h
diff --git a/components/autofill/core/browser/autofill_metrics.h b/components/autofill/core/browser/autofill_metrics.h
index f3d378cd9a8a9b246ed864d32ab83a1e5b7ae33b..2699e23b089dc94f5c25541bb87f5a7979e85fed 100644
--- a/components/autofill/core/browser/autofill_metrics.h
+++ b/components/autofill/core/browser/autofill_metrics.h
@@ -22,6 +22,12 @@ namespace autofill {
class AutofillMetrics {
public:
+ enum AutofillProfileAction {
+ EXISTING_PROFILE_USED,
+ EXISTING_PROFILE_UPDATED,
+ NEW_PROFILE_CREATED,
rkaplow 2015/10/07 15:04:56 should have something like AUTOFILL_PROFILE_ACTION
sebsg 2015/10/08 14:55:05 Done.
+ };
+
enum DeveloperEngagementMetric {
// Parsed a form that is potentially autofillable.
FILLABLE_FORM_PARSED = 0,
@@ -576,9 +582,9 @@ class AutofillMetrics {
// This should be called each time a server response is parsed for a form.
static void LogServerResponseHasDataForForm(bool has_data);
- // This should be called at each form submission to indicate whether a new
- // profile was created.
- static void LogAutomaticProfileCreation(bool created);
+ // This should be called at each form submission to indicate what profile
+ // action happened.
+ static void LogProfileActionOnFormSubmitted(AutofillProfileAction action);
// Utility to autofill form events in the relevant histograms depending on
// the presence of server and/or local data.

Powered by Google App Engine
This is Rietveld 408576698